@@ -140,7 +140,9 @@ class HTTPProtocol(BaseGopherProtocol):
 
     def renderdirend(self, entry):
         retstr = "</TABLE><HR>\n[<A HREF=\"/\">server top</A>]"
-        retstr += " [<A HREF=\"%s\">view with gopher</A>]" % entry.geturl()
+        retstr += " [<A HREF=\"%s\">view with gopher</A>]" % \
+                  entry.geturl(self.server.server_name,
+                               self.server.server_port)
         retstr += '<BR>Generated by <A HREF="%s">%s</A>' % (
             pygopherd.version.homepage, pygopherd.version.productname)
         return retstr + "\n</BODY></HTML>\n"
