@@ -26,7 +26,11 @@ import unittest
 from pygopherd import *
 
 def suite():
-    tests = [initializationTest
+    tests = [initializationTest,
+             GopherExceptionsTest,
+             fileextTest,
+             gopherentryTest,
+             loggerTest
         ]
     suite = unittest.TestSuite()
     for module in tests:
